<?php
/**
 * griddy theme functions and definitions
 * @since v. 0.1
 */
    // bring in scripts for theme specific options
include_once (get_template_directory() . '/include/theme-options.php');

function griddy_setup() {
        global $content_width;
	/* Set the $content_width for things such as video embeds. */
	if ( !isset( $content_width ) )
            $content_width = 502;

    // custom editor style support
    add_editor_style( 'editor-style.css' );
    
    // This theme uses Featured Images (also known as post thumbnails)
    add_theme_support('post-thumbnails'); 
    //set_post_thumbnail_size( 150, 150 );

    // Add default posts and comments RSS feed links to head
    add_theme_support('automatic-feed-links');

    // language support - add your translation
    load_theme_textdomain('griddy', get_template_directory_uri() . '/languages');

    // This theme uses wp_nav_menu in one location.
    register_nav_menus(array(
        'primary' => __('Primary Navigation', 'griddy'),
        ));  

    //customer header image banner support 
    add_theme_support( 'custom-header' );
    $defaults = array(
    'default-image'          => get_template_directory_uri() . '/images/default-header.jpg', 
    'random-default'         => false,
    'width'                  => 480,
    'height'                 => 450,
    'flex-height'            => false,
    'flex-width'             => false,
    'repeat'                 => 'no-repeat',
    'header-text'            => false,
    'uploads'                => true,
    'wp-head-callback'       => '',
    'admin-head-callback'    => '',
    'admin-preview-callback' => ''   
    );
    add_theme_support( 'custom-header', $defaults );

    // Add theme support for Custom Background
    add_theme_support( 'custom-background', array(
        'default-image' => '',
        'default-color' => 'fafafa',
    )); 
}
add_action('after_setup_theme', 'griddy_setup');



function griddy_add_theme_scripts() {    
   
    // Loads default main stylesheet and support script.
    wp_enqueue_style( 'style', get_stylesheet_uri() ); 
        // toggle reply comment form script
        wp_enqueue_script( 'griddy', get_template_directory_uri() . '/js/toggle.js', 
        array( 'jquery' ), '1.0', true
        );

    /**
     * Adds JavaScript to pages with the comment form to support
     * sites with threaded comments (when in use).
     */
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
	wp_enqueue_script( 'comment-reply' );  
}
add_action( 'wp_enqueue_scripts', 'griddy_add_theme_scripts' );

    // add ie conditional html5 shim to header
function griddy_add_ie_html5_shim () {
    echo '<!--[if lt IE 9]>';
    echo '<script src="js/html5.js"></script>';
    echo '<![endif]-->';
}
    add_action('wp_head', 'griddy_add_ie_html5_shim');

    // font imported by enqueue method
    function griddy_add_google_fonts() {
    $protocol = is_ssl() ? 'https' : 'http';
    wp_enqueue_style( 'griddy-Oxygen', "$protocol://fonts.googleapis.com/css?family=Oxygen:400,300,700" );
    }     
    add_action( 'wp_enqueue_scripts', 'griddy_add_google_fonts', 5);
   
function griddy_widgets_init() {
        register_sidebar(array(
            'name' => __('Top Promo Left', 'griddy'),
            'id' => 'sidebar-1',
            'description' => __('Recommend text-widget for best results', 'griddy'),
            'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
        register_sidebar(array(
            'name' => __('Middle Page Area Left', 'griddy'),
            'id' => 'sidebar-2',
            'description' => __('Middle section of page home page only', 'griddy'),
            'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
        register_sidebar(array(
            'name' => __('Middle Page Area Right', 'griddy'),
            'id' => 'sidebar-3',
            'description' => __('Middle section of home page only', 'griddy'),
            'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
        register_sidebar(array(
            'name' => __('Widget Area Right of Content', 'griddy'),
            'id' => 'sidebar-4',
            'description' => __('Widget area only shows in Content pages', 'griddy'),
            'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
        register_sidebar(array(
            'name' => __('Widget Area Centered in Footer', 'griddy'),
            'id' => 'sidebar-5',
            'description' => __('The middle/only footer widget area', 'griddy'),
            'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
}
add_action( 'widgets_init', 'griddy_widgets_init' );

    //custom footer feature to replace credits
$author_url = 'http://tradesouthwest.com';
    add_action( 'widgets_init', 'griddy_widgets_init' );
    // footer credits added
function griddy_footer_credits() {
    $author_url = "http://tradesouthwest.com/";
    echo '<p><a href="'. esc_url_raw($author_url) .'"><small>Theme Griddy by Tradesouthwest</small></a></p>';
    
}
add_action( 'griddy_footer_credits', 'griddy_footer_credits' );

?>